@@ -23,15 +23,33 @@
 
 #include <libexif/exif-data.h>
 
-void action_tag_table        (const char *filename, ExifData *);
-void action_tag_list         (const char *filename, ExifData *,
-                              unsigned char ids);
-void action_tag_list_machine (const char *filename, ExifData *,
-                              unsigned char ids);
-void action_tag_list_xml     (const char *filename, ExifData *,
-                              unsigned char ids);
+typedef struct {
+	ExifTag tag;
+	ExifIfd ifd;
 
-void action_mnote_list       (const char *filename, ExifData *,
-                              unsigned char ids);
+	unsigned int machine_readable;
+	unsigned int use_ids;
+
+	const char *fin;
+
+	const char *set_value;
+	const char *set_thumb;
+} ExifParams;
+
+void action_insert_thumb     (ExifData *, ExifLog *, ExifParams);
+void action_remove_thumb     (ExifData *, ExifLog *, ExifParams);
+void action_show_tag         (ExifData *, ExifLog *, ExifParams);
+void action_set_value        (ExifData *, ExifLog *, ExifParams);
+void action_remove_tag       (ExifData *, ExifLog *, ExifParams);
+
+void action_save             (ExifData *, ExifLog *, ExifParams, const char *);
+void action_save_thumb       (ExifData *, ExifLog *, ExifParams, const char *);
+
+void action_tag_table        (ExifData *, ExifParams);
+void action_tag_list         (ExifData *, ExifParams);
+void action_tag_list_machine (ExifData *, ExifParams);
+void action_tag_list_xml     (ExifData *, ExifParams);
+
+void action_mnote_list       (ExifData *, ExifParams);
 
 #endif /* __ACTIONS_H__ */
